# -*- coding: utf-8 -*-
#    phasecalculator calculates FGIPs, solvent similarity and VLE with SSIMPLE.
#    Copyright (C) 2019  Mark D. Driver
#
#    phasecalculator is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
Script for reading CSV file to Phases object.

@author: Mark
"""

import logging
import csv
import puresolventinformation.information as pureinf
from phasecalculator.classes.temperature import Temperature
from phasecalculator.classes.molecule import Molecule
from phasecalculator.classes.phase import Phase
from phasecalculator.classes.phases import Phases


logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

NAME_INCHIKEY_MAP = pureinf.get_name_inchikey_mapping()
INCHIKEY_SSIP_FILE_DICT = pureinf.get_ssip_file_dict()

def convert_csv_file_to_phases(csv_filename):
    """

    Parameters
    ----------
    csv_filename : TYPE
        DESCRIPTION.

    Returns
    -------
    TYPE
        DESCRIPTION.

    """
    csv_file_contents = read_csv_file(csv_filename)
    return create_phases(csv_file_contents)

def read_csv_file(csv_filename):
    """

    Parameters
    ----------
    csv_filename : TYPE
        DESCRIPTION.

    Returns
    -------
    list
        DESCRIPTION.

    """
    with open(csv_filename, "r") as csv_file:
        csv_reader = csv.reader(csv_file, delimiter="\t")
        return [row for row in csv_reader]

def create_phases(csv_file_contents):
    """

    Parameters
    ----------
    csv_file_contents : TYPE
        DESCRIPTION.

    Returns
    -------
    TYPE
        DESCRIPTION.

    """
    phase_list = []
    for csv_file_line in csv_file_contents:
        phase_list.append(create_phase(csv_file_line))
    return Phases(phase_list)
    


def create_phase(csv_file_line):
    """
    

    Parameters
    ----------
    csv_file_line : TYPE
        DESCRIPTION.

    Returns
    -------
    TYPE
        DESCRIPTION.

    """
    temperature = create_temperature(float(csv_file_line[0]))
    molecule_list = []
    for i in range(1,len(csv_file_line),2):
        name = csv_file_line[i]
        molefraction = float(csv_file_line[i+1])
        molecule_list.append(create_molecule(name, molefraction))
    return Phase(molecule_list, temperature)

def create_molecule(name, molefraction):
    """

    Parameters
    ----------
    name : TYPE
        DESCRIPTION.
    molefraction : TYPE
        DESCRIPTION.

    Raises
    ------
    keyerr
        DESCRIPTION.

    Returns
    -------
    TYPE
        DESCRIPTION.

    """
    try:
        inchikey = NAME_INCHIKEY_MAP[name]
        ssip_file_loc = INCHIKEY_SSIP_FILE_DICT[inchikey]
        return Molecule(name, inchikey, ssip_file_loc, molefraction)
    except KeyError as keyerr:
        LOGGER.error("Invalid entry: %s Not found.", name)
        raise keyerr

def create_temperature(temperature_value):
    """

    Parameters
    ----------
    temperature_value : TYPE
        DESCRIPTION.

    Returns
    -------
    TYPE
        DESCRIPTION.

    """
    return Temperature(temperature_value, "KELVIN")